import requests
import json

class compendium(object):
    def __init__(self, url="https://botw-compendium.herokuapp.com/api/v1"):
        self.url = url

    def categoryList(self):
        return ["creatures", "equipment", "materials", "monsters", "treasure"]

    def getCategory(self, categoryName: str, timeout=None):
        categoryData = requests. \
            get(f"{self.url}/category/{categoryName.lower()}", timeout=timeout). \
            json()
        return categoryData["data"]

    def getEntry(self, entry, timeout=None):
        try:
            target = entry.replace(" ", "%20").lower()
        except:
            target = entry
        try:
            entryData = requests. \
                get(f"{self.url}/entry/{target}", timeout=timeout). \
                json()
        except json.decoder.JSONDecodeError:
            raise ValueError("Invalid entry.")

        return entryData["data"]

    def getAll(self, timeout=None):
        allData = requests. \
            get(self.url, timeout=timeout). \
            json()

        return allData["data"]


import setuptools

setuptools.setup(
    name='pyrule-compendium',
    version='1.0.0',
    author='Aarav Borthakur',
    author_email='gadhaguy13@gmail.com',
    description='The official python wrapper for the Hyrule Compendium API',
    long_description=open('README.md', 'r').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/gadhagod/pyrule-compendium',
    packages=setuptools.find_packages(),
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
    install_requires=['requests']
)
